/* This file was generated by PyBindGen 0.0.0.0 */
#define PY_SSIZE_T_CLEAN
#include <Python.h>
#include <stddef.h>


#if PY_VERSION_HEX >= 0x03000000
#if PY_VERSION_HEX >= 0x03050000
typedef PyAsyncMethods* cmpfunc;
#else
typedef void* cmpfunc;
#endif
#define PyCObject_FromVoidPtr(a, b) PyCapsule_New(a, NULL, b)
#define PyCObject_AsVoidPtr(a) PyCapsule_GetPointer(a, NULL)
#define PyString_FromString(a) PyBytes_FromString(a)
#define Py_TPFLAGS_CHECKTYPES 0 /* this flag doesn't exist in python 3 */
#endif


#if     __GNUC__ > 2
# define PYBINDGEN_UNUSED(param) param __attribute__((__unused__))
#elif     __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 4)
# define PYBINDGEN_UNUSED(param) __attribute__((__unused__)) param
#else
# define PYBINDGEN_UNUSED(param) param
#endif  /* !__GNUC__ */

#ifndef _PyBindGenWrapperFlags_defined_
#define _PyBindGenWrapperFlags_defined_
typedef enum _PyBindGenWrapperFlags {
   PYBINDGEN_WRAPPER_FLAG_NONE = 0,
   PYBINDGEN_WRAPPER_FLAG_OBJECT_NOT_OWNED = (1<<0),
} PyBindGenWrapperFlags;
#endif

#if PY_VERSION_HEX >= 0x03070000 && !defined(PyEval_ThreadsInitialized)
#define PyEval_ThreadsInitialized() 1
#endif


#include "wrapper_go.h"
/* --- module functions --- */


PyObject *
_wrap__wrapper_GoPyInit(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;

    GoPyInit();
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_GoPyInit(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_DecRef(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    DecRef(handle);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_DecRef(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_IncRef(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    IncRef(handle);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_IncRef(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_NumHandles(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int retval;

    retval = NumHandles();
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_NumHandles(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_bool_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_bool_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_bool_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_bool_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_bool_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_bool_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_bool_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    bool retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_bool_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "N", PyBool_FromLong(retval));
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_bool_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_bool_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_bool_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_bool_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_bool_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    bool value;
    PyObject *py_value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LiO", (char **) keywords, &handle, &idx, &py_value)) {
        return NULL;
    }
    value = (bool) PyObject_IsTrue(py_value);
    Slice_bool_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_bool_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_bool_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    bool value;
    PyObject *py_value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LO", (char **) keywords, &handle, &py_value)) {
        return NULL;
    }
    value = (bool) PyObject_IsTrue(py_value);
    Slice_bool_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_bool_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_byte_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_byte_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_byte_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_byte_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_byte_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_byte_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_byte_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    uint8_t retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_byte_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "i", (int)retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_byte_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_byte_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_byte_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_byte_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_byte_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    int value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    if (value > 0xff) {
        PyErr_SetString(PyExc_ValueError, "Out of range");
        return NULL;
    }
    Slice_byte_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_byte_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_byte_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    if (value > 0xff) {
        PyErr_SetString(PyExc_ValueError, "Out of range");
        return NULL;
    }
    Slice_byte_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_byte_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_byte_from_bytes(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    PyObject *o;
    const char *keywords[] = {"o", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "O", (char **) keywords, &o)) {
        return NULL;
    }
    retval = Slice_byte_from_bytes(o);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_byte_from_bytes(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_byte_to_bytes(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    PyObject *retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_byte_to_bytes(handle);
    py_retval = Py_BuildValue((char *) "N", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_byte_to_bytes(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_error_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_error_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_error_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_error_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_error_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_error_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_error_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    char *retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_error_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "s", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_error_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_error_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_error_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_error_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_error_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    char *value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lis", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    Slice_error_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_error_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_error_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    char *value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Ls", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    Slice_error_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_error_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_float32_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_float32_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_float32_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_float32_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_float32_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_float32_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_float32_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    float retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_float32_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "f", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_float32_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_float32_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_float32_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_float32_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_float32_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    float value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lif", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    Slice_float32_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_float32_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_float32_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    float value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lf", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    Slice_float32_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_float32_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_float64_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_float64_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_float64_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_float64_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_float64_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_float64_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_float64_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    double retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_float64_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "d", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_float64_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_float64_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_float64_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_float64_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_float64_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    double value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lid", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    Slice_float64_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_float64_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_float64_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    double value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Ld", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    Slice_float64_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_float64_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_int_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_int_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_int_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_int_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_int_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    int64_t value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LiL", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    Slice_int_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int64_t value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LL", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    Slice_int_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int16_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_int16_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int16_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_int16_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_int16_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int16_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int16_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int16_t retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_int16_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int16_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int16_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_int16_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int16_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int16_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    int value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    if (value > 0x7fff) {
        PyErr_SetString(PyExc_ValueError, "Out of range");
        return NULL;
    }
    Slice_int16_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int16_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int16_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    if (value > 0x7fff) {
        PyErr_SetString(PyExc_ValueError, "Out of range");
        return NULL;
    }
    Slice_int16_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int16_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int32_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_int32_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int32_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_int32_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_int32_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int32_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int32_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int32_t retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_int32_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int32_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int32_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_int32_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int32_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int32_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    int32_t value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    Slice_int32_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int32_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int32_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int32_t value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    Slice_int32_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int32_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int64_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_int64_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int64_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_int64_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_int64_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int64_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int64_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_int64_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int64_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int64_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_int64_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int64_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int64_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    int64_t value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LiL", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    Slice_int64_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int64_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int64_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int64_t value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LL", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    Slice_int64_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int64_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int8_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_int8_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int8_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_int8_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_int8_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int8_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int8_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int8_t retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_int8_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int8_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int8_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_int8_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int8_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int8_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    int value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    if (value > 0x7f) {
        PyErr_SetString(PyExc_ValueError, "Out of range");
        return NULL;
    }
    Slice_int8_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int8_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_int8_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    if (value > 0x7f) {
        PyErr_SetString(PyExc_ValueError, "Out of range");
        return NULL;
    }
    Slice_int8_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_int8_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_rune_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_rune_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_rune_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_rune_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_rune_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_rune_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_rune_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int32_t retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_rune_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_rune_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_rune_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_rune_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_rune_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_rune_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    int32_t value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    Slice_rune_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_rune_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_rune_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int32_t value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    Slice_rune_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_rune_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_string_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_string_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_string_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_string_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_string_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_string_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_string_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    char *retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_string_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "s", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_string_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_string_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_string_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_string_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_string_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    char *value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lis", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    Slice_string_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_string_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_string_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    char *value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Ls", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    Slice_string_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_string_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_uint_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_uint_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_uint_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    uint64_t retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_uint_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "K", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_uint_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    uint64_t value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LiK", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    Slice_uint_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    uint64_t value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LK", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    Slice_uint_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint16_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_uint16_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint16_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_uint16_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_uint16_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint16_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint16_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    uint16_t retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_uint16_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint16_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint16_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_uint16_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint16_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint16_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    int value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    if (value > 0xffff) {
        PyErr_SetString(PyExc_ValueError, "Out of range");
        return NULL;
    }
    Slice_uint16_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint16_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint16_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    if (value > 0xffff) {
        PyErr_SetString(PyExc_ValueError, "Out of range");
        return NULL;
    }
    Slice_uint16_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint16_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint32_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_uint32_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint32_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_uint32_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_uint32_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint32_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint32_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    uint32_t retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_uint32_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "N", PyLong_FromUnsignedLong(retval));
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint32_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint32_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_uint32_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint32_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint32_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    unsigned int value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LiI", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    Slice_uint32_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint32_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint32_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    unsigned int value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LI", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    Slice_uint32_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint32_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint64_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_uint64_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint64_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_uint64_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_uint64_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint64_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint64_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    uint64_t retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_uint64_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "K", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint64_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint64_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_uint64_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint64_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint64_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    uint64_t value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LiK", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    Slice_uint64_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint64_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint64_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    uint64_t value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LK", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    Slice_uint64_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint64_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint8_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = Slice_uint8_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint8_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_Slice_uint8_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int retval;
    int64_t handle;
    const char *keywords[] = {"handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &handle)) {
        return NULL;
    }
    retval = Slice_uint8_len(handle);
    py_retval = Py_BuildValue((char *) "i", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint8_len(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint8_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    uint8_t retval;
    int64_t handle;
    int idx;
    const char *keywords[] = {"handle", "idx", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &idx)) {
        return NULL;
    }
    retval = Slice_uint8_elem(handle, idx);
    py_retval = Py_BuildValue((char *) "i", (int)retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint8_elem(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint8_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t handle;
    int st;
    int ed;
    const char *keywords[] = {"handle", "st", "ed", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &st, &ed)) {
        return NULL;
    }
    retval = Slice_uint8_subslice(handle, st, ed);
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint8_subslice(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint8_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int idx;
    int value;
    const char *keywords[] = {"handle", "idx", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lii", (char **) keywords, &handle, &idx, &value)) {
        return NULL;
    }
    if (value > 0xff) {
        PyErr_SetString(PyExc_ValueError, "Out of range");
        return NULL;
    }
    Slice_uint8_set(handle, idx, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint8_set(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_Slice_uint8_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t handle;
    int value;
    const char *keywords[] = {"handle", "value", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Li", (char **) keywords, &handle, &value)) {
        return NULL;
    }
    if (value > 0xff) {
        PyErr_SetString(PyExc_ValueError, "Out of range");
        return NULL;
    }
    Slice_uint8_append(handle, value);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_Slice_uint8_append(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_EmptyEvent(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = client_EmptyEvent();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_EmptyEvent(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_client_Set_EmptyEvent(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t val;
    const char *keywords[] = {"val", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &val)) {
        return NULL;
    }
    client_Set_EmptyEvent(val);
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_client_Set_EmptyEvent(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedDynamicClient_Resource(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    char *apiVersion;
    char *kind;
    const char *keywords[] = {"_handle", "apiVersion", "kind", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Lss", (char **) keywords, &_handle, &apiVersion, &kind)) {
        return NULL;
    }
    retval = client_WrappedDynamicClient_Resource(_handle, apiVersion, kind);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedDynamicClient_Resource(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedNamespaceableResourceInterface_Apply(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    char *name;
    int64_t obj;
    int64_t opts;
    int64_t subresources;
    const char *keywords[] = {"_handle", "name", "obj", "opts", "subresources", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LsLLL", (char **) keywords, &_handle, &name, &obj, &opts, &subresources)) {
        return NULL;
    }
    retval = client_WrappedNamespaceableResourceInterface_Apply(_handle, name, obj, opts, subresources);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Apply(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedNamespaceableResourceInterface_ApplyStatus(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    char *name;
    int64_t obj;
    int64_t opts;
    const char *keywords[] = {"_handle", "name", "obj", "opts", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LsLL", (char **) keywords, &_handle, &name, &obj, &opts)) {
        return NULL;
    }
    retval = client_WrappedNamespaceableResourceInterface_ApplyStatus(_handle, name, obj, opts);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedNamespaceableResourceInterface_ApplyStatus(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedNamespaceableResourceInterface_Create(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    int64_t obj;
    int64_t opts;
    int64_t subresources;
    const char *keywords[] = {"_handle", "obj", "opts", "subresources", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LLLL", (char **) keywords, &_handle, &obj, &opts, &subresources)) {
        return NULL;
    }
    retval = client_WrappedNamespaceableResourceInterface_Create(_handle, obj, opts, subresources);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Create(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedNamespaceableResourceInterface_Delete(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    char *retval;
    int64_t _handle;
    char *name;
    int64_t opts;
    int64_t subresources;
    const char *keywords[] = {"_handle", "name", "opts", "subresources", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LsLL", (char **) keywords, &_handle, &name, &opts, &subresources)) {
        return NULL;
    }
    retval = client_WrappedNamespaceableResourceInterface_Delete(_handle, name, opts, subresources);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "s", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Delete(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedNamespaceableResourceInterface_DeleteCollection(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    char *retval;
    int64_t _handle;
    int64_t opts;
    int64_t listOptions;
    const char *keywords[] = {"_handle", "opts", "listOptions", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LLL", (char **) keywords, &_handle, &opts, &listOptions)) {
        return NULL;
    }
    retval = client_WrappedNamespaceableResourceInterface_DeleteCollection(_handle, opts, listOptions);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "s", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedNamespaceableResourceInterface_DeleteCollection(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedNamespaceableResourceInterface_Get(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    char *name;
    int64_t opts;
    int64_t subresources;
    const char *keywords[] = {"_handle", "name", "opts", "subresources", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LsLL", (char **) keywords, &_handle, &name, &opts, &subresources)) {
        return NULL;
    }
    retval = client_WrappedNamespaceableResourceInterface_Get(_handle, name, opts, subresources);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Get(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedNamespaceableResourceInterface_List(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    int64_t opts;
    const char *keywords[] = {"_handle", "opts", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LL", (char **) keywords, &_handle, &opts)) {
        return NULL;
    }
    retval = client_WrappedNamespaceableResourceInterface_List(_handle, opts);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedNamespaceableResourceInterface_List(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedNamespaceableResourceInterface_Namespace(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    char *arg_0;
    const char *keywords[] = {"_handle", "arg_0", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "Ls", (char **) keywords, &_handle, &arg_0)) {
        return NULL;
    }
    retval = client_WrappedNamespaceableResourceInterface_Namespace(_handle, arg_0);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Namespace(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedNamespaceableResourceInterface_Patch(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    char *name;
    char *pt;
    int64_t data;
    int64_t opts;
    int64_t subresources;
    const char *keywords[] = {"_handle", "name", "pt", "data", "opts", "subresources", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LssLLL", (char **) keywords, &_handle, &name, &pt, &data, &opts, &subresources)) {
        return NULL;
    }
    retval = client_WrappedNamespaceableResourceInterface_Patch(_handle, name, pt, data, opts, subresources);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Patch(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedNamespaceableResourceInterface_Update(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    int64_t obj;
    int64_t opts;
    int64_t subresources;
    const char *keywords[] = {"_handle", "obj", "opts", "subresources", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LLLL", (char **) keywords, &_handle, &obj, &opts, &subresources)) {
        return NULL;
    }
    retval = client_WrappedNamespaceableResourceInterface_Update(_handle, obj, opts, subresources);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Update(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedNamespaceableResourceInterface_UpdateStatus(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    int64_t obj;
    int64_t opts;
    const char *keywords[] = {"_handle", "obj", "opts", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LLL", (char **) keywords, &_handle, &obj, &opts)) {
        return NULL;
    }
    retval = client_WrappedNamespaceableResourceInterface_UpdateStatus(_handle, obj, opts);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedNamespaceableResourceInterface_UpdateStatus(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedNamespaceableResourceInterface_Watch(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    int64_t opts;
    const char *keywords[] = {"_handle", "opts", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LL", (char **) keywords, &_handle, &opts)) {
        return NULL;
    }
    retval = client_WrappedNamespaceableResourceInterface_Watch(_handle, opts);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Watch(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedResourceInterface_Apply(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    char *name;
    int64_t obj;
    int64_t opts;
    int64_t subresources;
    const char *keywords[] = {"_handle", "name", "obj", "opts", "subresources", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LsLLL", (char **) keywords, &_handle, &name, &obj, &opts, &subresources)) {
        return NULL;
    }
    retval = client_WrappedResourceInterface_Apply(_handle, name, obj, opts, subresources);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedResourceInterface_Apply(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedResourceInterface_ApplyStatus(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    char *name;
    int64_t obj;
    int64_t opts;
    const char *keywords[] = {"_handle", "name", "obj", "opts", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LsLL", (char **) keywords, &_handle, &name, &obj, &opts)) {
        return NULL;
    }
    retval = client_WrappedResourceInterface_ApplyStatus(_handle, name, obj, opts);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedResourceInterface_ApplyStatus(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedResourceInterface_Create(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    int64_t obj;
    int64_t opts;
    int64_t subresources;
    const char *keywords[] = {"_handle", "obj", "opts", "subresources", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LLLL", (char **) keywords, &_handle, &obj, &opts, &subresources)) {
        return NULL;
    }
    retval = client_WrappedResourceInterface_Create(_handle, obj, opts, subresources);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedResourceInterface_Create(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedResourceInterface_Delete(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    char *retval;
    int64_t _handle;
    char *name;
    int64_t opts;
    int64_t subresources;
    const char *keywords[] = {"_handle", "name", "opts", "subresources", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LsLL", (char **) keywords, &_handle, &name, &opts, &subresources)) {
        return NULL;
    }
    retval = client_WrappedResourceInterface_Delete(_handle, name, opts, subresources);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "s", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedResourceInterface_Delete(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedResourceInterface_DeleteCollection(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    char *retval;
    int64_t _handle;
    int64_t opts;
    int64_t listOptions;
    const char *keywords[] = {"_handle", "opts", "listOptions", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LLL", (char **) keywords, &_handle, &opts, &listOptions)) {
        return NULL;
    }
    retval = client_WrappedResourceInterface_DeleteCollection(_handle, opts, listOptions);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "s", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedResourceInterface_DeleteCollection(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedResourceInterface_Get(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    char *name;
    int64_t opts;
    int64_t subresources;
    const char *keywords[] = {"_handle", "name", "opts", "subresources", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LsLL", (char **) keywords, &_handle, &name, &opts, &subresources)) {
        return NULL;
    }
    retval = client_WrappedResourceInterface_Get(_handle, name, opts, subresources);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedResourceInterface_Get(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedResourceInterface_List(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    int64_t opts;
    const char *keywords[] = {"_handle", "opts", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LL", (char **) keywords, &_handle, &opts)) {
        return NULL;
    }
    retval = client_WrappedResourceInterface_List(_handle, opts);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedResourceInterface_List(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedResourceInterface_Patch(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    char *name;
    char *pt;
    int64_t data;
    int64_t opts;
    int64_t subresources;
    const char *keywords[] = {"_handle", "name", "pt", "data", "opts", "subresources", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LssLLL", (char **) keywords, &_handle, &name, &pt, &data, &opts, &subresources)) {
        return NULL;
    }
    retval = client_WrappedResourceInterface_Patch(_handle, name, pt, data, opts, subresources);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedResourceInterface_Patch(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedResourceInterface_Update(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    int64_t obj;
    int64_t opts;
    int64_t subresources;
    const char *keywords[] = {"_handle", "obj", "opts", "subresources", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LLLL", (char **) keywords, &_handle, &obj, &opts, &subresources)) {
        return NULL;
    }
    retval = client_WrappedResourceInterface_Update(_handle, obj, opts, subresources);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedResourceInterface_Update(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedResourceInterface_UpdateStatus(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    int64_t obj;
    int64_t opts;
    const char *keywords[] = {"_handle", "obj", "opts", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LLL", (char **) keywords, &_handle, &obj, &opts)) {
        return NULL;
    }
    retval = client_WrappedResourceInterface_UpdateStatus(_handle, obj, opts);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedResourceInterface_UpdateStatus(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedResourceInterface_Watch(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    int64_t opts;
    const char *keywords[] = {"_handle", "opts", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LL", (char **) keywords, &_handle, &opts)) {
        return NULL;
    }
    retval = client_WrappedResourceInterface_Watch(_handle, opts);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedResourceInterface_Watch(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedWatchInterface_Next(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    const char *keywords[] = {"_handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &_handle)) {
        return NULL;
    }
    retval = client_WrappedWatchInterface_Next(_handle);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedWatchInterface_Next(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_WrappedWatchInterface_Stop(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t _handle;
    bool goRun;
    PyObject *py_goRun;
    const char *keywords[] = {"_handle", "goRun", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LO", (char **) keywords, &_handle, &py_goRun)) {
        return NULL;
    }
    goRun = (bool) PyObject_IsTrue(py_goRun);
    client_WrappedWatchInterface_Stop(_handle, goRun);
    if (PyErr_Occurred()) {
        return NULL;
    }
    Py_INCREF(Py_None);
    py_retval = Py_None;
    return py_retval;
}
PyObject * _wrap__wrapper_client_WrappedWatchInterface_Stop(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_NewWrappedDynamicClient(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    float qps;
    int64_t burst;
    char *timeout;
    const char *keywords[] = {"qps", "burst", "timeout", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "fLs", (char **) keywords, &qps, &burst, &timeout)) {
        return NULL;
    }
    retval = client_NewWrappedDynamicClient(qps, burst, timeout);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_NewWrappedDynamicClient(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_NewWrappedDynamicClientWithConfig(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t config;
    float qps;
    int64_t burst;
    char *timeout;
    const char *keywords[] = {"config", "qps", "burst", "timeout", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LfLs", (char **) keywords, &config, &qps, &burst, &timeout)) {
        return NULL;
    }
    retval = client_NewWrappedDynamicClientWithConfig(config, qps, burst, timeout);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_NewWrappedDynamicClientWithConfig(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_client_NewWrappedWatchInterface(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t watcher;
    const char *keywords[] = {"watcher", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &watcher)) {
        return NULL;
    }
    retval = client_NewWrappedWatchInterface(watcher);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_client_NewWrappedWatchInterface(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_setup_SetupEnvTestResult_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = setup_SetupEnvTestResult_CTor();
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_setup_SetupEnvTestResult_CTor(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_setup_SetupEnvTest(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t stdin_data;
    int64_t arg_data;
    const char *keywords[] = {"stdin_data", "arg_data", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "LL", (char **) keywords, &stdin_data, &arg_data)) {
        return NULL;
    }
    retval = setup_SetupEnvTest(stdin_data, arg_data);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_setup_SetupEnvTest(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_server_EnvTestEnvironment_GetKubeConfig(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    const char *keywords[] = {"_handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &_handle)) {
        return NULL;
    }
    retval = server_EnvTestEnvironment_GetKubeConfig(_handle);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_server_EnvTestEnvironment_GetKubeConfig(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_server_EnvTestEnvironment_Start(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    int64_t _handle;
    const char *keywords[] = {"_handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &_handle)) {
        return NULL;
    }
    retval = server_EnvTestEnvironment_Start(_handle);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_server_EnvTestEnvironment_Start(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_server_EnvTestEnvironment_Stop(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    char *retval;
    int64_t _handle;
    const char *keywords[] = {"_handle", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "L", (char **) keywords, &_handle)) {
        return NULL;
    }
    retval = server_EnvTestEnvironment_Stop(_handle);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "s", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_server_EnvTestEnvironment_Stop(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);


PyObject *
_wrap__wrapper_server_NewEnvTestEnvironment(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs))
{
    PyObject *py_retval;
    int64_t retval;

    retval = server_NewEnvTestEnvironment();
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_server_NewEnvTestEnvironment(PyObject *PYBINDGEN_UNUSED(_args), PyObject *PYBINDGEN_UNUSED(_kwargs));


PyObject *
_wrap__wrapper_server_NewEnvTestEnvironmentWithPath(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs)
{
    PyObject *py_retval;
    int64_t retval;
    char *path;
    const char *keywords[] = {"path", NULL};

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, (char *) "s", (char **) keywords, &path)) {
        return NULL;
    }
    retval = server_NewEnvTestEnvironmentWithPath(path);
    if (PyErr_Occurred()) {
        return NULL;
    }
    py_retval = Py_BuildValue((char *) "L", retval);
    return py_retval;
}
PyObject * _wrap__wrapper_server_NewEnvTestEnvironmentWithPath(PyObject * PYBINDGEN_UNUSED(dummy), PyObject *args, PyObject *kwargs);

static PyMethodDef _wrapper_functions[] = {
    {(char *) "GoPyInit", (PyCFunction) _wrap__wrapper_GoPyInit, METH_NOARGS, "GoPyInit()\n\n" },
    {(char *) "DecRef", (PyCFunction) _wrap__wrapper_DecRef, METH_KEYWORDS|METH_VARARGS, "DecRef(handle)\n\ntype: handle: int64_t" },
    {(char *) "IncRef", (PyCFunction) _wrap__wrapper_IncRef, METH_KEYWORDS|METH_VARARGS, "IncRef(handle)\n\ntype: handle: int64_t" },
    {(char *) "NumHandles", (PyCFunction) _wrap__wrapper_NumHandles, METH_NOARGS, "NumHandles()\n\n" },
    {(char *) "Slice_bool_CTor", (PyCFunction) _wrap__wrapper_Slice_bool_CTor, METH_NOARGS, "Slice_bool_CTor()\n\n" },
    {(char *) "Slice_bool_len", (PyCFunction) _wrap__wrapper_Slice_bool_len, METH_KEYWORDS|METH_VARARGS, "Slice_bool_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_bool_elem", (PyCFunction) _wrap__wrapper_Slice_bool_elem, METH_KEYWORDS|METH_VARARGS, "Slice_bool_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_bool_subslice", (PyCFunction) _wrap__wrapper_Slice_bool_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_bool_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_bool_set", (PyCFunction) _wrap__wrapper_Slice_bool_set, METH_KEYWORDS|METH_VARARGS, "Slice_bool_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: bool" },
    {(char *) "Slice_bool_append", (PyCFunction) _wrap__wrapper_Slice_bool_append, METH_KEYWORDS|METH_VARARGS, "Slice_bool_append(handle, value)\n\ntype: handle: int64_t\ntype: value: bool" },
    {(char *) "Slice_byte_CTor", (PyCFunction) _wrap__wrapper_Slice_byte_CTor, METH_NOARGS, "Slice_byte_CTor()\n\n" },
    {(char *) "Slice_byte_len", (PyCFunction) _wrap__wrapper_Slice_byte_len, METH_KEYWORDS|METH_VARARGS, "Slice_byte_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_byte_elem", (PyCFunction) _wrap__wrapper_Slice_byte_elem, METH_KEYWORDS|METH_VARARGS, "Slice_byte_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_byte_subslice", (PyCFunction) _wrap__wrapper_Slice_byte_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_byte_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_byte_set", (PyCFunction) _wrap__wrapper_Slice_byte_set, METH_KEYWORDS|METH_VARARGS, "Slice_byte_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: uint8_t" },
    {(char *) "Slice_byte_append", (PyCFunction) _wrap__wrapper_Slice_byte_append, METH_KEYWORDS|METH_VARARGS, "Slice_byte_append(handle, value)\n\ntype: handle: int64_t\ntype: value: uint8_t" },
    {(char *) "Slice_byte_from_bytes", (PyCFunction) _wrap__wrapper_Slice_byte_from_bytes, METH_KEYWORDS|METH_VARARGS, "Slice_byte_from_bytes(o)\n\ntype: o: PyObject *" },
    {(char *) "Slice_byte_to_bytes", (PyCFunction) _wrap__wrapper_Slice_byte_to_bytes, METH_KEYWORDS|METH_VARARGS, "Slice_byte_to_bytes(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_error_CTor", (PyCFunction) _wrap__wrapper_Slice_error_CTor, METH_NOARGS, "Slice_error_CTor()\n\n" },
    {(char *) "Slice_error_len", (PyCFunction) _wrap__wrapper_Slice_error_len, METH_KEYWORDS|METH_VARARGS, "Slice_error_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_error_elem", (PyCFunction) _wrap__wrapper_Slice_error_elem, METH_KEYWORDS|METH_VARARGS, "Slice_error_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_error_subslice", (PyCFunction) _wrap__wrapper_Slice_error_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_error_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_error_set", (PyCFunction) _wrap__wrapper_Slice_error_set, METH_KEYWORDS|METH_VARARGS, "Slice_error_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: char *" },
    {(char *) "Slice_error_append", (PyCFunction) _wrap__wrapper_Slice_error_append, METH_KEYWORDS|METH_VARARGS, "Slice_error_append(handle, value)\n\ntype: handle: int64_t\ntype: value: char *" },
    {(char *) "Slice_float32_CTor", (PyCFunction) _wrap__wrapper_Slice_float32_CTor, METH_NOARGS, "Slice_float32_CTor()\n\n" },
    {(char *) "Slice_float32_len", (PyCFunction) _wrap__wrapper_Slice_float32_len, METH_KEYWORDS|METH_VARARGS, "Slice_float32_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_float32_elem", (PyCFunction) _wrap__wrapper_Slice_float32_elem, METH_KEYWORDS|METH_VARARGS, "Slice_float32_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_float32_subslice", (PyCFunction) _wrap__wrapper_Slice_float32_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_float32_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_float32_set", (PyCFunction) _wrap__wrapper_Slice_float32_set, METH_KEYWORDS|METH_VARARGS, "Slice_float32_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: float" },
    {(char *) "Slice_float32_append", (PyCFunction) _wrap__wrapper_Slice_float32_append, METH_KEYWORDS|METH_VARARGS, "Slice_float32_append(handle, value)\n\ntype: handle: int64_t\ntype: value: float" },
    {(char *) "Slice_float64_CTor", (PyCFunction) _wrap__wrapper_Slice_float64_CTor, METH_NOARGS, "Slice_float64_CTor()\n\n" },
    {(char *) "Slice_float64_len", (PyCFunction) _wrap__wrapper_Slice_float64_len, METH_KEYWORDS|METH_VARARGS, "Slice_float64_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_float64_elem", (PyCFunction) _wrap__wrapper_Slice_float64_elem, METH_KEYWORDS|METH_VARARGS, "Slice_float64_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_float64_subslice", (PyCFunction) _wrap__wrapper_Slice_float64_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_float64_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_float64_set", (PyCFunction) _wrap__wrapper_Slice_float64_set, METH_KEYWORDS|METH_VARARGS, "Slice_float64_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: double" },
    {(char *) "Slice_float64_append", (PyCFunction) _wrap__wrapper_Slice_float64_append, METH_KEYWORDS|METH_VARARGS, "Slice_float64_append(handle, value)\n\ntype: handle: int64_t\ntype: value: double" },
    {(char *) "Slice_int_CTor", (PyCFunction) _wrap__wrapper_Slice_int_CTor, METH_NOARGS, "Slice_int_CTor()\n\n" },
    {(char *) "Slice_int_len", (PyCFunction) _wrap__wrapper_Slice_int_len, METH_KEYWORDS|METH_VARARGS, "Slice_int_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_int_elem", (PyCFunction) _wrap__wrapper_Slice_int_elem, METH_KEYWORDS|METH_VARARGS, "Slice_int_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_int_subslice", (PyCFunction) _wrap__wrapper_Slice_int_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_int_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_int_set", (PyCFunction) _wrap__wrapper_Slice_int_set, METH_KEYWORDS|METH_VARARGS, "Slice_int_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: int64_t" },
    {(char *) "Slice_int_append", (PyCFunction) _wrap__wrapper_Slice_int_append, METH_KEYWORDS|METH_VARARGS, "Slice_int_append(handle, value)\n\ntype: handle: int64_t\ntype: value: int64_t" },
    {(char *) "Slice_int16_CTor", (PyCFunction) _wrap__wrapper_Slice_int16_CTor, METH_NOARGS, "Slice_int16_CTor()\n\n" },
    {(char *) "Slice_int16_len", (PyCFunction) _wrap__wrapper_Slice_int16_len, METH_KEYWORDS|METH_VARARGS, "Slice_int16_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_int16_elem", (PyCFunction) _wrap__wrapper_Slice_int16_elem, METH_KEYWORDS|METH_VARARGS, "Slice_int16_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_int16_subslice", (PyCFunction) _wrap__wrapper_Slice_int16_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_int16_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_int16_set", (PyCFunction) _wrap__wrapper_Slice_int16_set, METH_KEYWORDS|METH_VARARGS, "Slice_int16_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: int16_t" },
    {(char *) "Slice_int16_append", (PyCFunction) _wrap__wrapper_Slice_int16_append, METH_KEYWORDS|METH_VARARGS, "Slice_int16_append(handle, value)\n\ntype: handle: int64_t\ntype: value: int16_t" },
    {(char *) "Slice_int32_CTor", (PyCFunction) _wrap__wrapper_Slice_int32_CTor, METH_NOARGS, "Slice_int32_CTor()\n\n" },
    {(char *) "Slice_int32_len", (PyCFunction) _wrap__wrapper_Slice_int32_len, METH_KEYWORDS|METH_VARARGS, "Slice_int32_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_int32_elem", (PyCFunction) _wrap__wrapper_Slice_int32_elem, METH_KEYWORDS|METH_VARARGS, "Slice_int32_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_int32_subslice", (PyCFunction) _wrap__wrapper_Slice_int32_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_int32_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_int32_set", (PyCFunction) _wrap__wrapper_Slice_int32_set, METH_KEYWORDS|METH_VARARGS, "Slice_int32_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: int32_t" },
    {(char *) "Slice_int32_append", (PyCFunction) _wrap__wrapper_Slice_int32_append, METH_KEYWORDS|METH_VARARGS, "Slice_int32_append(handle, value)\n\ntype: handle: int64_t\ntype: value: int32_t" },
    {(char *) "Slice_int64_CTor", (PyCFunction) _wrap__wrapper_Slice_int64_CTor, METH_NOARGS, "Slice_int64_CTor()\n\n" },
    {(char *) "Slice_int64_len", (PyCFunction) _wrap__wrapper_Slice_int64_len, METH_KEYWORDS|METH_VARARGS, "Slice_int64_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_int64_elem", (PyCFunction) _wrap__wrapper_Slice_int64_elem, METH_KEYWORDS|METH_VARARGS, "Slice_int64_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_int64_subslice", (PyCFunction) _wrap__wrapper_Slice_int64_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_int64_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_int64_set", (PyCFunction) _wrap__wrapper_Slice_int64_set, METH_KEYWORDS|METH_VARARGS, "Slice_int64_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: int64_t" },
    {(char *) "Slice_int64_append", (PyCFunction) _wrap__wrapper_Slice_int64_append, METH_KEYWORDS|METH_VARARGS, "Slice_int64_append(handle, value)\n\ntype: handle: int64_t\ntype: value: int64_t" },
    {(char *) "Slice_int8_CTor", (PyCFunction) _wrap__wrapper_Slice_int8_CTor, METH_NOARGS, "Slice_int8_CTor()\n\n" },
    {(char *) "Slice_int8_len", (PyCFunction) _wrap__wrapper_Slice_int8_len, METH_KEYWORDS|METH_VARARGS, "Slice_int8_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_int8_elem", (PyCFunction) _wrap__wrapper_Slice_int8_elem, METH_KEYWORDS|METH_VARARGS, "Slice_int8_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_int8_subslice", (PyCFunction) _wrap__wrapper_Slice_int8_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_int8_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_int8_set", (PyCFunction) _wrap__wrapper_Slice_int8_set, METH_KEYWORDS|METH_VARARGS, "Slice_int8_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: int8_t" },
    {(char *) "Slice_int8_append", (PyCFunction) _wrap__wrapper_Slice_int8_append, METH_KEYWORDS|METH_VARARGS, "Slice_int8_append(handle, value)\n\ntype: handle: int64_t\ntype: value: int8_t" },
    {(char *) "Slice_rune_CTor", (PyCFunction) _wrap__wrapper_Slice_rune_CTor, METH_NOARGS, "Slice_rune_CTor()\n\n" },
    {(char *) "Slice_rune_len", (PyCFunction) _wrap__wrapper_Slice_rune_len, METH_KEYWORDS|METH_VARARGS, "Slice_rune_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_rune_elem", (PyCFunction) _wrap__wrapper_Slice_rune_elem, METH_KEYWORDS|METH_VARARGS, "Slice_rune_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_rune_subslice", (PyCFunction) _wrap__wrapper_Slice_rune_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_rune_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_rune_set", (PyCFunction) _wrap__wrapper_Slice_rune_set, METH_KEYWORDS|METH_VARARGS, "Slice_rune_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: int32_t" },
    {(char *) "Slice_rune_append", (PyCFunction) _wrap__wrapper_Slice_rune_append, METH_KEYWORDS|METH_VARARGS, "Slice_rune_append(handle, value)\n\ntype: handle: int64_t\ntype: value: int32_t" },
    {(char *) "Slice_string_CTor", (PyCFunction) _wrap__wrapper_Slice_string_CTor, METH_NOARGS, "Slice_string_CTor()\n\n" },
    {(char *) "Slice_string_len", (PyCFunction) _wrap__wrapper_Slice_string_len, METH_KEYWORDS|METH_VARARGS, "Slice_string_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_string_elem", (PyCFunction) _wrap__wrapper_Slice_string_elem, METH_KEYWORDS|METH_VARARGS, "Slice_string_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_string_subslice", (PyCFunction) _wrap__wrapper_Slice_string_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_string_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_string_set", (PyCFunction) _wrap__wrapper_Slice_string_set, METH_KEYWORDS|METH_VARARGS, "Slice_string_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: char *" },
    {(char *) "Slice_string_append", (PyCFunction) _wrap__wrapper_Slice_string_append, METH_KEYWORDS|METH_VARARGS, "Slice_string_append(handle, value)\n\ntype: handle: int64_t\ntype: value: char *" },
    {(char *) "Slice_uint_CTor", (PyCFunction) _wrap__wrapper_Slice_uint_CTor, METH_NOARGS, "Slice_uint_CTor()\n\n" },
    {(char *) "Slice_uint_len", (PyCFunction) _wrap__wrapper_Slice_uint_len, METH_KEYWORDS|METH_VARARGS, "Slice_uint_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_uint_elem", (PyCFunction) _wrap__wrapper_Slice_uint_elem, METH_KEYWORDS|METH_VARARGS, "Slice_uint_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_uint_subslice", (PyCFunction) _wrap__wrapper_Slice_uint_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_uint_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_uint_set", (PyCFunction) _wrap__wrapper_Slice_uint_set, METH_KEYWORDS|METH_VARARGS, "Slice_uint_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: uint64_t" },
    {(char *) "Slice_uint_append", (PyCFunction) _wrap__wrapper_Slice_uint_append, METH_KEYWORDS|METH_VARARGS, "Slice_uint_append(handle, value)\n\ntype: handle: int64_t\ntype: value: uint64_t" },
    {(char *) "Slice_uint16_CTor", (PyCFunction) _wrap__wrapper_Slice_uint16_CTor, METH_NOARGS, "Slice_uint16_CTor()\n\n" },
    {(char *) "Slice_uint16_len", (PyCFunction) _wrap__wrapper_Slice_uint16_len, METH_KEYWORDS|METH_VARARGS, "Slice_uint16_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_uint16_elem", (PyCFunction) _wrap__wrapper_Slice_uint16_elem, METH_KEYWORDS|METH_VARARGS, "Slice_uint16_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_uint16_subslice", (PyCFunction) _wrap__wrapper_Slice_uint16_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_uint16_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_uint16_set", (PyCFunction) _wrap__wrapper_Slice_uint16_set, METH_KEYWORDS|METH_VARARGS, "Slice_uint16_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: uint16_t" },
    {(char *) "Slice_uint16_append", (PyCFunction) _wrap__wrapper_Slice_uint16_append, METH_KEYWORDS|METH_VARARGS, "Slice_uint16_append(handle, value)\n\ntype: handle: int64_t\ntype: value: uint16_t" },
    {(char *) "Slice_uint32_CTor", (PyCFunction) _wrap__wrapper_Slice_uint32_CTor, METH_NOARGS, "Slice_uint32_CTor()\n\n" },
    {(char *) "Slice_uint32_len", (PyCFunction) _wrap__wrapper_Slice_uint32_len, METH_KEYWORDS|METH_VARARGS, "Slice_uint32_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_uint32_elem", (PyCFunction) _wrap__wrapper_Slice_uint32_elem, METH_KEYWORDS|METH_VARARGS, "Slice_uint32_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_uint32_subslice", (PyCFunction) _wrap__wrapper_Slice_uint32_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_uint32_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_uint32_set", (PyCFunction) _wrap__wrapper_Slice_uint32_set, METH_KEYWORDS|METH_VARARGS, "Slice_uint32_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: uint32_t" },
    {(char *) "Slice_uint32_append", (PyCFunction) _wrap__wrapper_Slice_uint32_append, METH_KEYWORDS|METH_VARARGS, "Slice_uint32_append(handle, value)\n\ntype: handle: int64_t\ntype: value: uint32_t" },
    {(char *) "Slice_uint64_CTor", (PyCFunction) _wrap__wrapper_Slice_uint64_CTor, METH_NOARGS, "Slice_uint64_CTor()\n\n" },
    {(char *) "Slice_uint64_len", (PyCFunction) _wrap__wrapper_Slice_uint64_len, METH_KEYWORDS|METH_VARARGS, "Slice_uint64_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_uint64_elem", (PyCFunction) _wrap__wrapper_Slice_uint64_elem, METH_KEYWORDS|METH_VARARGS, "Slice_uint64_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_uint64_subslice", (PyCFunction) _wrap__wrapper_Slice_uint64_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_uint64_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_uint64_set", (PyCFunction) _wrap__wrapper_Slice_uint64_set, METH_KEYWORDS|METH_VARARGS, "Slice_uint64_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: uint64_t" },
    {(char *) "Slice_uint64_append", (PyCFunction) _wrap__wrapper_Slice_uint64_append, METH_KEYWORDS|METH_VARARGS, "Slice_uint64_append(handle, value)\n\ntype: handle: int64_t\ntype: value: uint64_t" },
    {(char *) "Slice_uint8_CTor", (PyCFunction) _wrap__wrapper_Slice_uint8_CTor, METH_NOARGS, "Slice_uint8_CTor()\n\n" },
    {(char *) "Slice_uint8_len", (PyCFunction) _wrap__wrapper_Slice_uint8_len, METH_KEYWORDS|METH_VARARGS, "Slice_uint8_len(handle)\n\ntype: handle: int64_t" },
    {(char *) "Slice_uint8_elem", (PyCFunction) _wrap__wrapper_Slice_uint8_elem, METH_KEYWORDS|METH_VARARGS, "Slice_uint8_elem(handle, idx)\n\ntype: handle: int64_t\ntype: idx: int" },
    {(char *) "Slice_uint8_subslice", (PyCFunction) _wrap__wrapper_Slice_uint8_subslice, METH_KEYWORDS|METH_VARARGS, "Slice_uint8_subslice(handle, st, ed)\n\ntype: handle: int64_t\ntype: st: int\ntype: ed: int" },
    {(char *) "Slice_uint8_set", (PyCFunction) _wrap__wrapper_Slice_uint8_set, METH_KEYWORDS|METH_VARARGS, "Slice_uint8_set(handle, idx, value)\n\ntype: handle: int64_t\ntype: idx: int\ntype: value: uint8_t" },
    {(char *) "Slice_uint8_append", (PyCFunction) _wrap__wrapper_Slice_uint8_append, METH_KEYWORDS|METH_VARARGS, "Slice_uint8_append(handle, value)\n\ntype: handle: int64_t\ntype: value: uint8_t" },
    {(char *) "client_EmptyEvent", (PyCFunction) _wrap__wrapper_client_EmptyEvent, METH_NOARGS, "client_EmptyEvent()\n\n" },
    {(char *) "client_Set_EmptyEvent", (PyCFunction) _wrap__wrapper_client_Set_EmptyEvent, METH_KEYWORDS|METH_VARARGS, "client_Set_EmptyEvent(val)\n\ntype: val: int64_t" },
    {(char *) "client_WrappedDynamicClient_Resource", (PyCFunction) _wrap__wrapper_client_WrappedDynamicClient_Resource, METH_KEYWORDS|METH_VARARGS, "client_WrappedDynamicClient_Resource(_handle, apiVersion, kind)\n\ntype: _handle: int64_t\ntype: apiVersion: char *\ntype: kind: char *" },
    {(char *) "client_WrappedNamespaceableResourceInterface_Apply", (PyCFunction) _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Apply, METH_KEYWORDS|METH_VARARGS, "client_WrappedNamespaceableResourceInterface_Apply(_handle, name, obj, opts, subresources)\n\ntype: _handle: int64_t\ntype: name: char *\ntype: obj: int64_t\ntype: opts: int64_t\ntype: subresources: int64_t" },
    {(char *) "client_WrappedNamespaceableResourceInterface_ApplyStatus", (PyCFunction) _wrap__wrapper_client_WrappedNamespaceableResourceInterface_ApplyStatus, METH_KEYWORDS|METH_VARARGS, "client_WrappedNamespaceableResourceInterface_ApplyStatus(_handle, name, obj, opts)\n\ntype: _handle: int64_t\ntype: name: char *\ntype: obj: int64_t\ntype: opts: int64_t" },
    {(char *) "client_WrappedNamespaceableResourceInterface_Create", (PyCFunction) _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Create, METH_KEYWORDS|METH_VARARGS, "client_WrappedNamespaceableResourceInterface_Create(_handle, obj, opts, subresources)\n\ntype: _handle: int64_t\ntype: obj: int64_t\ntype: opts: int64_t\ntype: subresources: int64_t" },
    {(char *) "client_WrappedNamespaceableResourceInterface_Delete", (PyCFunction) _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Delete, METH_KEYWORDS|METH_VARARGS, "client_WrappedNamespaceableResourceInterface_Delete(_handle, name, opts, subresources)\n\ntype: _handle: int64_t\ntype: name: char *\ntype: opts: int64_t\ntype: subresources: int64_t" },
    {(char *) "client_WrappedNamespaceableResourceInterface_DeleteCollection", (PyCFunction) _wrap__wrapper_client_WrappedNamespaceableResourceInterface_DeleteCollection, METH_KEYWORDS|METH_VARARGS, "client_WrappedNamespaceableResourceInterface_DeleteCollection(_handle, opts, listOptions)\n\ntype: _handle: int64_t\ntype: opts: int64_t\ntype: listOptions: int64_t" },
    {(char *) "client_WrappedNamespaceableResourceInterface_Get", (PyCFunction) _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Get, METH_KEYWORDS|METH_VARARGS, "client_WrappedNamespaceableResourceInterface_Get(_handle, name, opts, subresources)\n\ntype: _handle: int64_t\ntype: name: char *\ntype: opts: int64_t\ntype: subresources: int64_t" },
    {(char *) "client_WrappedNamespaceableResourceInterface_List", (PyCFunction) _wrap__wrapper_client_WrappedNamespaceableResourceInterface_List, METH_KEYWORDS|METH_VARARGS, "client_WrappedNamespaceableResourceInterface_List(_handle, opts)\n\ntype: _handle: int64_t\ntype: opts: int64_t" },
    {(char *) "client_WrappedNamespaceableResourceInterface_Namespace", (PyCFunction) _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Namespace, METH_KEYWORDS|METH_VARARGS, "client_WrappedNamespaceableResourceInterface_Namespace(_handle, arg_0)\n\ntype: _handle: int64_t\ntype: arg_0: char *" },
    {(char *) "client_WrappedNamespaceableResourceInterface_Patch", (PyCFunction) _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Patch, METH_KEYWORDS|METH_VARARGS, "client_WrappedNamespaceableResourceInterface_Patch(_handle, name, pt, data, opts, subresources)\n\ntype: _handle: int64_t\ntype: name: char *\ntype: pt: char *\ntype: data: int64_t\ntype: opts: int64_t\ntype: subresources: int64_t" },
    {(char *) "client_WrappedNamespaceableResourceInterface_Update", (PyCFunction) _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Update, METH_KEYWORDS|METH_VARARGS, "client_WrappedNamespaceableResourceInterface_Update(_handle, obj, opts, subresources)\n\ntype: _handle: int64_t\ntype: obj: int64_t\ntype: opts: int64_t\ntype: subresources: int64_t" },
    {(char *) "client_WrappedNamespaceableResourceInterface_UpdateStatus", (PyCFunction) _wrap__wrapper_client_WrappedNamespaceableResourceInterface_UpdateStatus, METH_KEYWORDS|METH_VARARGS, "client_WrappedNamespaceableResourceInterface_UpdateStatus(_handle, obj, opts)\n\ntype: _handle: int64_t\ntype: obj: int64_t\ntype: opts: int64_t" },
    {(char *) "client_WrappedNamespaceableResourceInterface_Watch", (PyCFunction) _wrap__wrapper_client_WrappedNamespaceableResourceInterface_Watch, METH_KEYWORDS|METH_VARARGS, "client_WrappedNamespaceableResourceInterface_Watch(_handle, opts)\n\ntype: _handle: int64_t\ntype: opts: int64_t" },
    {(char *) "client_WrappedResourceInterface_Apply", (PyCFunction) _wrap__wrapper_client_WrappedResourceInterface_Apply, METH_KEYWORDS|METH_VARARGS, "client_WrappedResourceInterface_Apply(_handle, name, obj, opts, subresources)\n\ntype: _handle: int64_t\ntype: name: char *\ntype: obj: int64_t\ntype: opts: int64_t\ntype: subresources: int64_t" },
    {(char *) "client_WrappedResourceInterface_ApplyStatus", (PyCFunction) _wrap__wrapper_client_WrappedResourceInterface_ApplyStatus, METH_KEYWORDS|METH_VARARGS, "client_WrappedResourceInterface_ApplyStatus(_handle, name, obj, opts)\n\ntype: _handle: int64_t\ntype: name: char *\ntype: obj: int64_t\ntype: opts: int64_t" },
    {(char *) "client_WrappedResourceInterface_Create", (PyCFunction) _wrap__wrapper_client_WrappedResourceInterface_Create, METH_KEYWORDS|METH_VARARGS, "client_WrappedResourceInterface_Create(_handle, obj, opts, subresources)\n\ntype: _handle: int64_t\ntype: obj: int64_t\ntype: opts: int64_t\ntype: subresources: int64_t" },
    {(char *) "client_WrappedResourceInterface_Delete", (PyCFunction) _wrap__wrapper_client_WrappedResourceInterface_Delete, METH_KEYWORDS|METH_VARARGS, "client_WrappedResourceInterface_Delete(_handle, name, opts, subresources)\n\ntype: _handle: int64_t\ntype: name: char *\ntype: opts: int64_t\ntype: subresources: int64_t" },
    {(char *) "client_WrappedResourceInterface_DeleteCollection", (PyCFunction) _wrap__wrapper_client_WrappedResourceInterface_DeleteCollection, METH_KEYWORDS|METH_VARARGS, "client_WrappedResourceInterface_DeleteCollection(_handle, opts, listOptions)\n\ntype: _handle: int64_t\ntype: opts: int64_t\ntype: listOptions: int64_t" },
    {(char *) "client_WrappedResourceInterface_Get", (PyCFunction) _wrap__wrapper_client_WrappedResourceInterface_Get, METH_KEYWORDS|METH_VARARGS, "client_WrappedResourceInterface_Get(_handle, name, opts, subresources)\n\ntype: _handle: int64_t\ntype: name: char *\ntype: opts: int64_t\ntype: subresources: int64_t" },
    {(char *) "client_WrappedResourceInterface_List", (PyCFunction) _wrap__wrapper_client_WrappedResourceInterface_List, METH_KEYWORDS|METH_VARARGS, "client_WrappedResourceInterface_List(_handle, opts)\n\ntype: _handle: int64_t\ntype: opts: int64_t" },
    {(char *) "client_WrappedResourceInterface_Patch", (PyCFunction) _wrap__wrapper_client_WrappedResourceInterface_Patch, METH_KEYWORDS|METH_VARARGS, "client_WrappedResourceInterface_Patch(_handle, name, pt, data, opts, subresources)\n\ntype: _handle: int64_t\ntype: name: char *\ntype: pt: char *\ntype: data: int64_t\ntype: opts: int64_t\ntype: subresources: int64_t" },
    {(char *) "client_WrappedResourceInterface_Update", (PyCFunction) _wrap__wrapper_client_WrappedResourceInterface_Update, METH_KEYWORDS|METH_VARARGS, "client_WrappedResourceInterface_Update(_handle, obj, opts, subresources)\n\ntype: _handle: int64_t\ntype: obj: int64_t\ntype: opts: int64_t\ntype: subresources: int64_t" },
    {(char *) "client_WrappedResourceInterface_UpdateStatus", (PyCFunction) _wrap__wrapper_client_WrappedResourceInterface_UpdateStatus, METH_KEYWORDS|METH_VARARGS, "client_WrappedResourceInterface_UpdateStatus(_handle, obj, opts)\n\ntype: _handle: int64_t\ntype: obj: int64_t\ntype: opts: int64_t" },
    {(char *) "client_WrappedResourceInterface_Watch", (PyCFunction) _wrap__wrapper_client_WrappedResourceInterface_Watch, METH_KEYWORDS|METH_VARARGS, "client_WrappedResourceInterface_Watch(_handle, opts)\n\ntype: _handle: int64_t\ntype: opts: int64_t" },
    {(char *) "client_WrappedWatchInterface_Next", (PyCFunction) _wrap__wrapper_client_WrappedWatchInterface_Next, METH_KEYWORDS|METH_VARARGS, "client_WrappedWatchInterface_Next(_handle)\n\ntype: _handle: int64_t" },
    {(char *) "client_WrappedWatchInterface_Stop", (PyCFunction) _wrap__wrapper_client_WrappedWatchInterface_Stop, METH_KEYWORDS|METH_VARARGS, "client_WrappedWatchInterface_Stop(_handle, goRun)\n\ntype: _handle: int64_t\ntype: goRun: bool" },
    {(char *) "client_NewWrappedDynamicClient", (PyCFunction) _wrap__wrapper_client_NewWrappedDynamicClient, METH_KEYWORDS|METH_VARARGS, "client_NewWrappedDynamicClient(qps, burst, timeout)\n\ntype: qps: float\ntype: burst: int64_t\ntype: timeout: char *" },
    {(char *) "client_NewWrappedDynamicClientWithConfig", (PyCFunction) _wrap__wrapper_client_NewWrappedDynamicClientWithConfig, METH_KEYWORDS|METH_VARARGS, "client_NewWrappedDynamicClientWithConfig(config, qps, burst, timeout)\n\ntype: config: int64_t\ntype: qps: float\ntype: burst: int64_t\ntype: timeout: char *" },
    {(char *) "client_NewWrappedWatchInterface", (PyCFunction) _wrap__wrapper_client_NewWrappedWatchInterface, METH_KEYWORDS|METH_VARARGS, "client_NewWrappedWatchInterface(watcher)\n\ntype: watcher: int64_t" },
    {(char *) "setup_SetupEnvTestResult_CTor", (PyCFunction) _wrap__wrapper_setup_SetupEnvTestResult_CTor, METH_NOARGS, "setup_SetupEnvTestResult_CTor()\n\n" },
    {(char *) "setup_SetupEnvTest", (PyCFunction) _wrap__wrapper_setup_SetupEnvTest, METH_KEYWORDS|METH_VARARGS, "setup_SetupEnvTest(stdin_data, arg_data)\n\ntype: stdin_data: int64_t\ntype: arg_data: int64_t" },
    {(char *) "server_EnvTestEnvironment_GetKubeConfig", (PyCFunction) _wrap__wrapper_server_EnvTestEnvironment_GetKubeConfig, METH_KEYWORDS|METH_VARARGS, "server_EnvTestEnvironment_GetKubeConfig(_handle)\n\ntype: _handle: int64_t" },
    {(char *) "server_EnvTestEnvironment_Start", (PyCFunction) _wrap__wrapper_server_EnvTestEnvironment_Start, METH_KEYWORDS|METH_VARARGS, "server_EnvTestEnvironment_Start(_handle)\n\ntype: _handle: int64_t" },
    {(char *) "server_EnvTestEnvironment_Stop", (PyCFunction) _wrap__wrapper_server_EnvTestEnvironment_Stop, METH_KEYWORDS|METH_VARARGS, "server_EnvTestEnvironment_Stop(_handle)\n\ntype: _handle: int64_t" },
    {(char *) "server_NewEnvTestEnvironment", (PyCFunction) _wrap__wrapper_server_NewEnvTestEnvironment, METH_NOARGS, "server_NewEnvTestEnvironment()\n\n" },
    {(char *) "server_NewEnvTestEnvironmentWithPath", (PyCFunction) _wrap__wrapper_server_NewEnvTestEnvironmentWithPath, METH_KEYWORDS|METH_VARARGS, "server_NewEnvTestEnvironmentWithPath(path)\n\ntype: path: char *" },
    {NULL, NULL, 0, NULL}
};
#if PY_VERSION_HEX >= 0x03000000
static struct PyModuleDef _wrapper_moduledef = {
    PyModuleDef_HEAD_INIT,
    "_wrapper",
    NULL,
    -1,
    _wrapper_functions,
};
#endif


#if PY_VERSION_HEX >= 0x03000000
    #define MOD_ERROR NULL
    #define MOD_INIT(name) PyObject* PyInit_##name(void)
    #define MOD_RETURN(val) val
#else
    #define MOD_ERROR
    #define MOD_INIT(name) void init##name(void)
    #define MOD_RETURN(val)
#endif
#if defined(__cplusplus)
extern "C"
#endif
#if defined(__GNUC__) && __GNUC__ >= 4
__attribute__ ((visibility("default")))
#endif


MOD_INIT(_wrapper)
{
    PyObject *m;
    #if PY_VERSION_HEX >= 0x03000000
    m = PyModule_Create(&_wrapper_moduledef);
    #else
    m = Py_InitModule3((char *) "_wrapper", _wrapper_functions, NULL);
    #endif
    if (m == NULL) {
        return MOD_ERROR;
    }
    return MOD_RETURN(m);
}
